PaymentStatus enum

Statuts de paiement

Inheritance
Available extensions

Values

pending → const PaymentStatus
const PaymentStatus('pending', 'En attente', '⏳')
processing → const PaymentStatus
const PaymentStatus('processing', 'En cours', '🔄')
completed → const PaymentStatus
const PaymentStatus('completed', 'Réussi', '✅')
failed → const PaymentStatus
const PaymentStatus('failed', 'Échoué', '❌')
cancelled → const PaymentStatus
const PaymentStatus('cancelled', 'Annulé', '🚫')
expired → const PaymentStatus
const PaymentStatus('expired', 'Expiré', '⏰')
refunded → const PaymentStatus
const PaymentStatus('refunded', 'Remboursé', '↩️')

Properties

hashCode int
The hash code for this object.
no setterinherited
icon String
final
index int
A numeric identifier for the enumerated value.
no setterinherited
isCompleted bool
no setter
isFailed bool
no setter
isPending bool
no setter
label String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) PaymentStatus

Constants

values → const List<PaymentStatus>
A constant List of the values in this enum, in order of their declaration.